@@ -51,7 +51,7 @@
  * @author      Matt Knapp <mdknapp[at]gmail[dot]com>
  * @author      Brett Stimmerman <brettstimmerman[at]gmail[dot]com>
  * @copyright   2005 Michal Migurski
- * @version     $Id: json.php 4432 2008-11-07 03:52:22Z flyguide $
+ * @version     $Id$
  * @license     http://www.opensource.org/licenses/bsd-license.php
  * @link        http://pear.php.net/pepr/pepr-proposal-show.php?id=198
  * @deprecated	since TYPO3 4.3, will be removed in TYPO3 4.5
@@ -116,6 +116,13 @@ define('SERVICES_JSON_SUPPRESS_ERRORS', 32);
  */
 class Services_JSON
 {
+	/**
+	 * Constructor
+	 */
+	function __construct() {
+		t3lib_div::deprecationLog("Class Services_JSON - since TYPO3 4.3, will be removed in TYPO3 4.6");
+	}
+
    /**
     * constructs a new JSON instance
     *
