@@ -296,7 +296,7 @@ class tx_em_Connection_ExtDirectServer {
 
 		$html = '';
 		if ($noSave) {
-			$html = $install->updatesForm($extKey, $list[$extKey], 1);
+			$html = $install->updatesForm($extKey, $list[$extKey], 1, '', '', FALSE);
 		} else {
 			$install->writeTsStyleConfig($extKey, $arr);
 		}
@@ -1617,4 +1617,4 @@ if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLA
 	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['typo3/sysext/em/classes/connection/class.tx_em_connection_extdirectserver.php']);
 }
 
-?>
\ No newline at end of file
+?>
