@@ -434,14 +434,29 @@ class tx_rtehtmlarea_base extends t3lib_rteapi {
 	 * @return	void
 	 */
 	protected function addPageStyle() {
-			// Get stylesheet file name from Page TSConfig if any
-		$filename = trim($this->thisConfig['contentCSS']) ? trim($this->thisConfig['contentCSS']) : 'EXT:' . $this->ID . '/res/contentcss/default.css';
 		$this->addStyleSheet(
 			'rtehtmlarea-page-style',
-			$this->getFullFileName($filename),
+			$this->getContentCssFileName(),
 			'htmlArea RTE Content CSS',
 			'alternate stylesheet'
-			);
+		);
+	}
+
+	/**
+	 * Get the name of the contentCSS file to use
+	 *
+	 * @return	the full file name of the content css file to use
+	 */
+	protected function getContentCssFileName() {
+			// Get stylesheet file name from Page TSConfig if any
+		$fileName = trim($this->thisConfig['contentCSS']);
+		if ($fileName) {
+			$filename = $this->getFullFileName($fileName);
+		}
+		if (!$fileName || !file_exists(PATH_site . $fileName) || !filesize(PATH_site . $fileName)) {
+			$fileName = $this->getFullFileName('EXT:' . $this->ID . '/res/contentcss/default.css');
+		}
+		return $fileName;
 	}
 
 	/**
@@ -902,9 +917,8 @@ class tx_rtehtmlarea_base extends t3lib_rteapi {
 		$configureRTEInJavascriptString .= '
 			RTEarea[editornumber].defaultPageStyle = "' . $this->writeTemporaryFile('', 'defaultPageStyle', 'css', $this->buildStyleSheet()) . '";';
 			// Setting the pageStyle
-		$filename = trim($this->thisConfig['contentCSS']) ? trim($this->thisConfig['contentCSS']) : 'EXT:' . $this->ID . '/res/contentcss/default.css';
 		$configureRTEInJavascriptString .= '
-			RTEarea[editornumber].pageStyle = "' . t3lib_div::createVersionNumberedFilename($this->getFullFileName($filename)) .'";';
+			RTEarea[editornumber].pageStyle = "' . t3lib_div::createVersionNumberedFilename($this->getContentCssFileName()) .'";';
 			// Process classes configuration
 		$classesConfigurationRequired = false;
 		foreach ($this->registeredPlugins as $pluginId => $plugin) {
